%define anolis_release 2

Summary:        Vulkan ICD desktop loader
Name:           vulkan-loader
Version:        1.3.234
Release:        %{anolis_release}%{?dist}

License:        ASL 2.0
URL:            https://github.com/KhronosGroup/Vulkan-Loader
Source0:        https://github.com/KhronosGroup/Vulkan-Loader/archive/refs/tags/v%{version}.tar.gz

BuildRequires:  gcc gcc-c++ cmake ninja-build
BuildRequires:  python3-devel
BuildRequires:  vulkan-headers = %{version}
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xrandr)

Provides:       vulkan = %{version}-%{release}
Obsoletes:      vulkan < %{version}-%{release}
Provides:       vulkan-filesystem = %{version}-%{release}
Obsoletes:      vulkan-filesystem < %{version}-%{release}

Recommends:       mesa-vulkan-drivers

%description
Vulkan is an explicit API, enabling direct control over how
GPUs actually work. As such, Vulkan supports systems that have
multiple GPUs, each running with a different driver, or ICD
(Installable Client Driver). Vulkan also supports multiple global
contexts (instances, in Vulkan terminology). The ICD loader is a
library that is placed between a Vulkan application and any number
of Vulkan drivers, in order to support multiple drivers and the
instance-level functionality that works across these drivers.
Additionally, the loader manages inserting Vulkan layer libraries,
such as validation layers, between an application and the drivers. 

This package provides the Khronos official Vulkan ICD desktop
loader for Windows, Linux, and MacOS.

%package        devel
Summary:        Development files for %{name}
Requires:       %{name} = %{version}-%{release}
Requires:       vulkan-headers
Provides:       vulkan-devel = %{version}-%{release}
Obsoletes:      vulkan-devel < %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary:        Doc files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1 -n Vulkan-Loader-%{version}


%build
%cmake -GNinja -DCMAKE_BUILD_TYPE=Release .
%cmake_build

%install
%cmake_install

mkdir -p %{buildroot}%{_sysconfdir}/vulkan/explicit_layer.d/
mkdir -p %{buildroot}%{_sysconfdir}/vulkan/implicit_layer.d/
mkdir -p %{buildroot}%{_datadir}/vulkan/explicit_layer.d/
mkdir -p %{buildroot}%{_datadir}/vulkan/implicit_layer.d/
mkdir -p %{buildroot}%{_sysconfdir}/vulkan/icd.d
mkdir -p %{buildroot}%{_datadir}/vulkan/icd.d

%generate_compatibility_deps

%files
%license LICENSE.txt
%dir %{_sysconfdir}/vulkan/
%dir %{_sysconfdir}/vulkan/explicit_layer.d/
%dir %{_sysconfdir}/vulkan/icd.d/
%dir %{_sysconfdir}/vulkan/implicit_layer.d/
%dir %{_datadir}/vulkan/
%dir %{_datadir}/vulkan/explicit_layer.d/
%dir %{_datadir}/vulkan/icd.d/
%dir %{_datadir}/vulkan/implicit_layer.d/
%dir %{abidir}
%{_libdir}/*.so.*
%{abidir}/*.dump

%files devel
%{_libdir}/pkgconfig/vulkan.pc
%{_libdir}/*.so

%files doc
%doc README.md CONTRIBUTING.md


%changelog
* Wed Apr 12 2023 Kun(llfl) <llfl@linux.alibaba.com> - 1.3.234-2
- optimize spec file

* Sat Nov 12 2022 Funda Wang <fundawang@yeah.net> - 1.3.234-1
- New version 1.3.234

* Fri Nov 11 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.3.211-7
- vulkan-loader should recommend not require mesa

* Fri Oct 14 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.3.211-6
- optimise spec file

* Wed Oct 12 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.3.211-5
- add abi & add doc package

* Sat May 7 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.3.211-4
- recover to require mesa-vulkan-drivers

* Sat May 7 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.3.211-3
- remove dependency of mesa-vulkan-drivers temporarily

* Thu Apr 14 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.3.211-2
- add provides to fix mesa-vulkan-drivers dependency

* Thu Apr 14 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.3.211-1
- init from upstream
